==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/kbibtexstringwidget.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXSTRINGWIDGET_H
#define KBIBTEXSTRINGWIDGET_H

#include <qwidget.h>

class BibTeXString;
class QLineEdit;
class QMultiLineEdit;

class KBibTeXStringWidget : public QWidget
{
    Q_OBJECT
public:
    KBibTeXStringWidget( BibTeXString *bibtexstring, bool isReadWrite, QWidget *parent = 0, const char *name = 0 );

    ~KBibTeXStringWidget();

    static QDialog::DialogCode execute( BibTeXString *bibtexstring, const QString& caption, bool isReadWrite, QWidget *parent = 0, const char *name = 0 );

private:
    BibTeXString* m_bibtexstring;
    QLineEdit *m_lineEditStringId;
    QMultiLineEdit *m_multiLineEditStringValue;

    void setupGUI();
    void setStringData();
    void getStringData();
};

#endif

==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/kbibtexstringwidget.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXSTRINGWIDGET_H
#define KBIBTEXSTRINGWIDGET_H

#include <qtabwidget.h>

class BibTeXString;
class QLineEdit;
class QMultiLineEdit;

class KBibTeXStringWidget : public QTabWidget
{
    Q_OBJECT
public:
    KBibTeXStringWidget( BibTeX::BibTeXString *bibtexstring, bool isReadWrite, QWidget *parent = 0, const char *name = 0 );

    ~KBibTeXStringWidget();

    static QDialog::DialogCode execute( BibTeX::BibTeXString *bibtexstring, bool isReadWrite, QWidget *parent = 0, const char *name = 0 );

private:
    BibTeX::BibTeXString* m_bibtexstring;
    QLineEdit *m_lineEditStringId;
    QMultiLineEdit *m_multiLineEditStringValue;
    QTextEdit *m_textEditSource;
    QWidget *m_sourceTab;

    void setupGUI();
    void setStringData();
    void getStringData();

private slots:
    void slotCurrentTabChanged( QWidget* newTab );

};

#endif
